==> LlmEmbeddingXrVizualization-0.1.0.tar.gz: LlmEmbeddingXrVizualization-0.1.0/setup.py <==
from setuptools import find_packages, setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="LlmEmbeddingXrVizualization",
    version="0.1.0",
    author="Rakeen Rouf & Akalpit",
    author_email="rakeenrouf@gmail.com",
    description="A package for visualizing embeddings spaces from Hugging Face models",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rmr327/LlmEmbeddingXrVizualization",
    packages=find_packages(),
    install_requires=[
        "bpy>=4.0.0,<5.0.0",
        "certifi>=2024.8.30,<2025.0.0",
        "charset-normalizer>=3.4.0,<4.0.0",
        "click>=8.1.7,<9.0.0",
        "contourpy>=1.3.1,<2.0.0",
        "cycler>=0.12.1,<1.0.0",
        "Cython>=3.0.11,<4.0.0",
        "exceptiongroup>=1.2.2,<2.0.0",
        "filelock>=3.13.1,<4.0.0",
        "fonttools>=4.55.0,<5.0.0",
        "fsspec>=2024.2.0,<2025.0.0",
        "huggingface-hub>=0.26.3,<1.0.0",
        "idna>=3.10,<4.0.0",
        "iniconfig>=2.0.0,<3.0.0",
        "Jinja2>=3.1.3,<4.0.0",
        "joblib>=1.4.2,<2.0.0",
        "kiwisolver>=1.4.7,<2.0.0",
        "llvmlite>=0.43.0,<1.0.0",
        "MarkupSafe>=2.1.5,<3.0.0",
        "mathutils>=3.3.0,<4.0.0",
        "matplotlib>=3.9.3,<4.0.0",
        "mpmath>=1.3.0,<2.0.0",
        "networkx>=3.2.1,<4.0.0",
        "numba>=0.60.0,<1.0.0",
        "numpy>=1.26.3,<2.0.0",
        "nvidia-cublas-cu11>=11.11.3.6,<12.0.0",
        "nvidia-cuda-cupti-cu11>=11.8.87,<12.0.0",
        "nvidia-cuda-nvrtc-cu11>=11.8.89,<12.0.0",
        "nvidia-cuda-runtime-cu11>=11.8.89,<12.0.0",
        "nvidia-cudnn-cu11>=9.1.0.70,<10.0.0",
        "nvidia-cufft-cu11>=10.9.0.58,<11.0.0",
        "nvidia-curand-cu11>=10.3.0.86,<11.0.0",
        "nvidia-cusolver-cu11>=11.4.1.48,<12.0.0",
        "nvidia-cusparse-cu11>=11.7.5.86,<12.0.0",
        "nvidia-nccl-cu11>=2.21.5,<3.0.0",
        "nvidia-nvtx-cu11>=11.8.86,<12.0.0",
        "packaging>=24.2,<25.0",
        "pandas>=2.2.3,<3.0.0",
        "pillow>=10.2.0,<11.0.0",
        "plotly>=5.24.1,<6.0.0",
        "pluggy>=1.5.0,<2.0.0",
        "pynndescent>=0.5.13,<1.0.0",
        "pyparsing>=3.2.0,<4.0.0",
        "pytest>=8.3.3,<9.0.0",
        "python-dateutil>=2.9.0.post0,<3.0.0",
        "pytz>=2024.2,<2025.0",
        "PyYAML>=6.0.2,<7.0.0",
        "regex>=2024.11.6,<2025.0.0",
        "requests>=2.32.3,<3.0.0",
        "safetensors>=0.4.5,<1.0.0",
        "scikit-learn>=1.5.2,<2.0.0",
        "scipy>=1.14.1,<2.0.0",
        "six>=1.16.0,<2.0.0",
        "sympy>=1.13.1,<2.0.0",
        "tenacity>=9.0.0,<10.0.0",
        "threadpoolctl>=3.5.0,<4.0.0",
        "tokenizers>=0.20.3,<1.0.0",
        "tomli>=2.2.1,<3.0.0",
        "torch",
        "torchaudio",
        "torchvision",
        "tqdm>=4.67.1,<5.0.0",
        "transformers>=4.46.3,<5.0.0",
        "triton>=3.1.0,<4.0.0",
        "typing_extensions>=4.9.0,<5.0.0",
        "tzdata>=2024.2,<2025.0",
        "umap-learn>=0.5.6,<1.0.0",
        "urllib3>=2.2.3,<3.0.0",
        "xformers",
        "zstandard>=0.23.0,<1.0.0",
    ],
    entry_points={
        "console_scripts": [
            "llm-embedding-viz=src.plotverse_xr_llm:main",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)

==> LlmEmbeddingXrVizualization-0.1.1.tar.gz: LlmEmbeddingXrVizualization-0.1.1/setup.py <==
from setuptools import find_packages, setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="LlmEmbeddingXrVizualization",
    version="0.1.1",
    author="Rakeen Rouf & Akalpit",
    author_email="rakeenrouf@gmail.com",
    description="A package for visualizing embeddings spaces from Hugging Face models",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rmr327/LlmEmbeddingXrVizualization",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=[
        "bpy>=4.0.0,<5.0.0",
        "certifi>=2024.8.30,<2025.0.0",
        "charset-normalizer>=3.4.0,<4.0.0",
        "click>=8.1.7,<9.0.0",
        "contourpy>=1.3.1,<2.0.0",
        "cycler>=0.12.1,<1.0.0",
        "Cython>=3.0.11,<4.0.0",
        "exceptiongroup>=1.2.2,<2.0.0",
        "filelock>=3.13.1,<4.0.0",
        "fonttools>=4.55.0,<5.0.0",
        "fsspec>=2024.2.0,<2025.0.0",
        "huggingface-hub>=0.26.3,<1.0.0",
        "idna>=3.10,<4.0.0",
        "iniconfig>=2.0.0,<3.0.0",
        "Jinja2>=3.1.3,<4.0.0",
        "joblib>=1.4.2,<2.0.0",
        "kiwisolver>=1.4.7,<2.0.0",
        "llvmlite>=0.43.0,<1.0.0",
        "MarkupSafe>=2.1.5,<3.0.0",
        "mathutils>=3.3.0,<4.0.0",
        "matplotlib>=3.9.3,<4.0.0",
        "mpmath>=1.3.0,<2.0.0",
        "networkx>=3.2.1,<4.0.0",
        "numba>=0.60.0,<1.0.0",
        "numpy>=1.26.3,<2.0.0",
        "nvidia-cublas-cu11>=11.11.3.6,<12.0.0",
        "nvidia-cuda-cupti-cu11>=11.8.87,<12.0.0",
        "nvidia-cuda-nvrtc-cu11>=11.8.89,<12.0.0",
        "nvidia-cuda-runtime-cu11>=11.8.89,<12.0.0",
        "nvidia-cudnn-cu11>=9.1.0.70,<10.0.0",
        "nvidia-cufft-cu11>=10.9.0.58,<11.0.0",
        "nvidia-curand-cu11>=10.3.0.86,<11.0.0",
        "nvidia-cusolver-cu11>=11.4.1.48,<12.0.0",
        "nvidia-cusparse-cu11>=11.7.5.86,<12.0.0",
        "nvidia-nccl-cu11>=2.21.5,<3.0.0",
        "nvidia-nvtx-cu11>=11.8.86,<12.0.0",
        "packaging>=24.2,<25.0",
        "pandas>=2.2.3,<3.0.0",
        "pillow>=10.2.0,<11.0.0",
        "plotly>=5.24.1,<6.0.0",
        "pluggy>=1.5.0,<2.0.0",
        "pynndescent>=0.5.13,<1.0.0",
        "pyparsing>=3.2.0,<4.0.0",
        "pytest>=8.3.3,<9.0.0",
        "python-dateutil>=2.9.0.post0,<3.0.0",
        "pytz>=2024.2,<2025.0",
        "PyYAML>=6.0.2,<7.0.0",
        "regex>=2024.11.6,<2025.0.0",
        "requests>=2.32.3,<3.0.0",
        "safetensors>=0.4.5,<1.0.0",
        "scikit-learn>=1.5.2,<2.0.0",
        "scipy>=1.14.1,<2.0.0",
        "six>=1.16.0,<2.0.0",
        "sympy>=1.13.1,<2.0.0",
        "tenacity>=9.0.0,<10.0.0",
        "threadpoolctl>=3.5.0,<4.0.0",
        "tokenizers>=0.20.3,<1.0.0",
        "tomli>=2.2.1,<3.0.0",
        "torch",
        "torchaudio",
        "torchvision",
        "tqdm>=4.67.1,<5.0.0",
        "transformers>=4.46.3,<5.0.0",
        "triton>=3.1.0,<4.0.0",
        "typing_extensions>=4.9.0,<5.0.0",
        "tzdata>=2024.2,<2025.0",
        "umap-learn>=0.5.6,<1.0.0",
        "urllib3>=2.2.3,<3.0.0",
        "xformers",
        "zstandard>=0.23.0,<1.0.0",
    ],
    entry_points={
        "console_scripts": [
            "llm-embedding-viz=src.plotverse_xr_llm:main",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
